@@ -18,6 +18,7 @@
 #include <KShell>
 
 #include <QPair>
+#include <QSize>
 
 // Required includes for subDirectoriesCount():
 #ifdef Q_OS_WIN
@@ -101,7 +102,7 @@ void extractDerivedProperties(QVariantMap &data)
     const auto width = data.value(QStringLiteral("width"));
     const auto height = data.value(QStringLiteral("height"));
     if (!width.isNull() && !height.isNull()) {
-        data.insert(QStringLiteral("dimensions"), i18nc("width × height", "%1 × %2", width.toInt(), height.toInt()));
+        data.insert(QStringLiteral("dimensions"), QSize(width.toInt(), height.toInt()));
     }
 
     bool okLatitude;
@@ -349,7 +350,7 @@ void FileMetaDataProviderPrivate::processFileItems()
     //   * Not Indexed
     //   * Indexed
 
-    bool multipleFileMode = m_fileItems.size() > 1;
+    bool singleFileMode = m_fileItems.size() <= 1;
 
     QStringList urls;
     urls.reserve(m_fileItems.size());
@@ -362,10 +363,10 @@ void FileMetaDataProviderPrivate::processFileItems()
         }
     }
 
-    if (multipleFileMode) {
-        insertFilesListBasicData();
-    } else {
+    if (singleFileMode) {
         insertSingleFileBasicData();
+    } else {
+        insertFilesListBasicData();
     }
 
     if (!urls.isEmpty()) {
@@ -375,7 +376,7 @@ void FileMetaDataProviderPrivate::processFileItems()
         // Don't use indexing when we have multiple files
         auto indexingMode = FileFetchJob::UseRealtimeIndexing::Disabled;
 
-        if (!multipleFileMode) {
+        if (singleFileMode) {
             // Fully indexed by Baloo
             indexingMode = FileFetchJob::UseRealtimeIndexing::Fallback;
 
